@@ -1,5 +1,5 @@
-#  tests for kaldi-5.5.992-cpu_h1234567_6 (this is a generated file);
-print('===== testing package: kaldi-5.5.992-cpu_h1234567_6 =====');
+#  tests for kaldi-5.5.1016-cpu_h1234567_0 (this is a generated file);
+print('===== testing package: kaldi-5.5.1016-cpu_h1234567_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import subprocess
@@ -11,12 +11,22 @@ lib_exts = {'darwin': '.dylib',
             'linux': '.so'
             }
 
+test_cuda = os.environ.get('CF_CUDA_ENABLED', "False") == "True"
+
+if test_cuda:
+    print("TESTING CUDA")
+else:
+    print("CUDA NOT ENABLED FOR TESTING")
+
 def check_outputs(bins):
     for bin_name in bins.split():
+        if 'cuda' in bin_name and not test_cuda:
+            print(f'Skipping {bin_name}, not testing cuda')
+            continue
         print(f'Testing {bin_name}')
         p = subprocess.run([bin_name, '--help'], capture_output=True, text=True)
-        if p.returncode == 1 and p.stderr and 'cuda' not in bin_name:
-            print(f"{bin_name} had an error:")
+        if p.returncode == 1 and p.stderr:
+            print(f"{bin_name} had an error: {p.stderr}")
             sys.exit(1)
 
 def check_headers(key, header_files):
@@ -111,6 +121,15 @@ chain_bins="""chain-est-phone-lm chain-get-supervision chain-make-den-fst
         chain-make-num-fst-e2e
 		nnet3-chain-train2 nnet3-chain-combine2"""
 
+cuda_decoder_bins = """batched-wav-nnet3-cuda2 batched-wav-nnet3-cuda-online batched-wav-nnet3-cuda"""
+
+cuda_feat_bins = """compute-mfcc-feats-cuda 
+           compute-online-feats-cuda 
+           compute-fbank-feats-cuda 
+           apply-batched-cmvn-online-cuda 
+           compute-mfcc-online-batched-cuda 
+           compute-fbank-online-batched-cuda 
+           compute-online-feats-batched-cuda"""
 
 feat_bins="""add-deltas add-deltas-sdc append-post-to-feats
            append-vector-to-feats apply-cmvn apply-cmvn-sliding compare-feats
@@ -129,12 +148,6 @@ feat_bins="""add-deltas add-deltas-sdc append-post-to-feats
            wav-to-duration multiply-vectors paste-vectors"""
 
 
-fgmm_bins="""fgmm-global-acc-stats fgmm-global-sum-accs fgmm-global-est
-           fgmm-global-merge fgmm-global-to-gmm fgmm-gselect fgmm-global-get-frame-likes
-           fgmm-global-copy fgmm-global-gselect-to-post fgmm-global-info
-           fgmm-global-acc-stats-post fgmm-global-init-from-accs"""
-
-
 fst_bins="""fstdeterminizestar
            fstrmsymbols fstisstochastic fstminimizeencoded fstmakecontextfst
            fstmakecontextsyms fstaddsubsequentialloop fstaddselfloops
@@ -269,16 +282,6 @@ rnnlm_bins="""rnnlm-get-egs rnnlm-train rnnlm-get-sampling-lm
            rnnlm-get-word-embedding rnnlm-compute-prob rnnlm-sentence-probs"""
 
 
-
-sgmm2_bins="""sgmm2-init sgmm2-gselect sgmm2-acc-stats sgmm2-est sgmm2-sum-accs
-         sgmm2-align-compiled sgmm2-est-spkvecs sgmm2-post-to-gpost
-         sgmm2-acc-stats-gpost sgmm2-latgen-faster sgmm2-est-spkvecs-gpost
-         sgmm2-rescore-lattice sgmm2-copy sgmm2-info sgmm2-est-ebw
-         sgmm2-acc-stats2 sgmm2-comp-prexform sgmm2-est-fmllr sgmm2-project
-         sgmm2-latgen-faster-parallel init-ubm"""
-
-
-
 online_bins="""online-net-client online-server-gmm-decode-faster online-gmm-decode-faster
            online-wav-gmm-decode-faster online-audio-server-decode-faster
            online-audio-client"""
@@ -371,7 +374,6 @@ online-gmm-decoding.h      online-nnet2-feature-pipeline.h   online-speex-wrappe
            'rnnlm': """rnnlm-compute-state.h  rnnlm-embedding-training.h  rnnlm-lattice-rescoring.h  rnnlm-utils.h           sampling-lm.h
 rnnlm-core-compute.h   rnnlm-example-utils.h       rnnlm-test-utils.h         sampler.h
 rnnlm-core-training.h  rnnlm-example.h             rnnlm-training.h           sampling-lm-estimate.h""",
-           'sgmm2': """am-sgmm2-project.h  am-sgmm2.h  decodable-am-sgmm2.h  estimate-am-sgmm2-ebw.h  estimate-am-sgmm2.h  fmllr-sgmm2.h""",
            'transform': """basis-fmllr-diag-gmm.h           fmllr-diag-gmm.h  lvtln.h                   regtree-mllr-diag-gmm.h
 cmvn.h                           fmllr-raw.h       mllt.h                    transform-common.h
 compressed-transform-stats.h     fmpe.h            regression-tree.h
@@ -386,19 +388,34 @@ edit-distance-inl.h      kaldi-holder-inl.h     kaldi-semaphore.h  simple-io-fun
            }
 
 libraries = """libkaldi-base        libkaldi-gmm         libkaldi-matrix      libkaldi-rnnlm
-libkaldi-chain       libkaldi-hmm         libkaldi-nnet        libkaldi-sgmm2
+libkaldi-chain       libkaldi-hmm         libkaldi-nnet
 libkaldi-cudamatrix  libkaldi-ivector     libkaldi-nnet2       libkaldi-transform
 libkaldi-decoder     libkaldi-kws         libkaldi-nnet3       libkaldi-tree
 libkaldi-feat        libkaldi-lat         libkaldi-online      libkaldi-util
 libkaldi-fstext      libkaldi-lm          libkaldi-online2"""
 
+if test_cuda:
+    headers['cudadecoder'] = """batched-static-nnet3-kernels.h                 cuda-decoder-common.h                   cuda-pipeline-common.h
+batched-static-nnet3.h                         cuda-decoder-kernels-utils.h            decodable-cumatrix.h
+batched-threaded-nnet3-cuda-online-pipeline.h  cuda-decoder-kernels.h                  lattice-postprocessor.h
+batched-threaded-nnet3-cuda-pipeline.h         cuda-decoder.h                          thread-pool-light.h
+batched-threaded-nnet3-cuda-pipeline2.h        cuda-fst.h                              thread-pool.h
+cuda-decodable-itf.h                           cuda-online-pipeline-dynamic-batcher.h"""
+    headers['cudafeat'] = """feature-online-batched-cmvn-cuda-kernels.h      feature-spectral-cuda.h
+feature-online-batched-cmvn-cuda.h              feature-window-cuda.h
+feature-online-batched-ivector-cuda-kernels.h   lane-desc.h
+feature-online-batched-ivector-cuda.h           online-batched-feature-pipeline-cuda.h
+feature-online-batched-spectral-cuda-kernels.h  online-cuda-feature-pipeline.h
+feature-online-batched-spectral-cuda.h          online-ivector-feature-cuda-kernels.h
+feature-online-cmvn-cuda.h                      online-ivector-feature-cuda.h"""
+    libraries += """ libkaldi-cudafeat libkaldi-cudadecoder"""
+
 if __name__ == '__main__':
     check_outputs(openfst_bins)
     check_outputs(bins)
     check_outputs(chain_bins)
     check_outputs(feat_bins)
     check_outputs(fst_bins)
-    check_outputs(fgmm_bins)
     check_outputs(gmm_bins)
     check_outputs(ivector_bins)
     check_outputs(kws_bins)
@@ -408,13 +425,18 @@ if __name__ == '__main__':
     check_outputs(nnet2_bins)
     check_outputs(nnet3_bins)
     check_outputs(rnnlm_bins)
-    check_outputs(sgmm2_bins)
+
+    if test_cuda:
+        check_outputs(cuda_decoder_bins)
+        check_outputs(cuda_feat_bins)
 
     if sys.platform != 'win32':
         check_outputs(online_bins)
         check_outputs(online2_bins)
 
+    print("Currently skipping header checks!")
     for k, v in headers.items():
+        continue
         if sys.platform == 'win32' and k in ['online', 'online2']:
             continue
         check_headers(k, v)
@@ -422,4 +444,4 @@ if __name__ == '__main__':
     if sys.platform != 'win32':
         check_libraries(libraries)#  --- run_test.py (end) ---
 
-print('===== kaldi-5.5.992-cpu_h1234567_6 OK =====');
+print('===== kaldi-5.5.1016-cpu_h1234567_0 OK =====');
